@@ -23,16 +23,21 @@ except ImportError:
 # # CLI Import example
 
 # import os
+# import sys
 # from asm_cli import asm
 
-# asm = asm.ServiceManager(os.path.join(os.path.dirname(os.path.abspath(__file__)), "settings.ini"))
-# asm.cli()
+# BASE_PATH=os.path.dirname(os.path.abspath(__file__))
+
+# if sys.platform.startswith('win32'):
+#     BASE_PATH=os.path.dirname(BASE_PATH)
+    
+# ASM=asm.ServiceManager(os.path.join(BASE_PATH,"cli-settings.ini"))
+# ASM.cli()
 ###########
 
 class ServiceManager:
     def __init__(self, settings_file=None):
-
-        self.parser = CreateParser().create_parser()
+        self.parser = CreateParser(settings_file).create_parser()
         self.valuespace = self.parser.parse_args(sys.argv[1:])
 
         if len(sys.argv[1:])==0:
@@ -65,7 +70,44 @@ class ServiceManager:
 
 
     def json_print(self, value):
-        print(json.dumps(value, indent=2, sort_keys=True, ensure_ascii=False))
+        print(json.dumps(value, indent=2, sort_keys=True, ensure_ascii=False).encode('utf-8'))
+
+    # def all_aliases(self , alias):
+    #     all_aliases_list = ["all_services", "all_adapters", "all_bridges", "all_mysql",\
+    #         "all_media_services", "all_servers", "all_tsdb", "all_repositories", "all_acs",\
+    #         "all_web_services", "all_ta_api", "all_adminapplication", "all_standaloneclient", "all_files", "all_files_services", "all_files_adapters",\
+    #         "all_files_bridges", "all_files_mysql", "all_files_media_services", "all_files_servers",\
+    #         "all_files_tsdb", "all_files_repositories", "all_files_acs", "all_files_web_services", "all_files_ta_api"]
+    #     if alias in all_aliases_list:
+    #         if "files" in alias:
+    #             return
+    #         elif:
+    #             if prop == 'all_services':
+    #                 result = asm.get_task("all")
+    #             elif prop = 'all_files':
+    #                 result = asm.get_files("all")
+    #             else:
+    #                 _, component_type = alias.split('_'):
+    #                 if component_type = "adapters":
+    #                     component_type = "adapter"
+    #                 elif component_type = "servers":
+    #                     component_type = "server"
+    #                 elif component_type = "tsdb":
+    #                     component_type = "tsdbserver"
+    #                 elif component_type = "repositories":
+    #                     component_type = "repositoryserver"
+    #                 elif component_type = "servers":
+    #                     component_type = "server"
+    #                 elif component_type = "servers":
+    #                     component_type = "server"
+    #                 elif component_type = "servers":
+    #                     component_type = "server"
+    #                 elif component_type = "servers":
+    #                     component_type = "server"
+    #                 elif component_type = "servers":
+    #                     component_type = "server"
+    #                 elif component_type = "servers":
+    #                     component_type = "server"
 
     def is_alias(self, component):
         aliases = self.asm.get_alias()
@@ -97,7 +139,7 @@ class ServiceManager:
         elif valuespace.command == "download":
             for url in valuespace.url:
                 if valuespace.auth:
-                    url = "{}://{}@{}".format(url.split("://")[0], valuespace.auth, url.split("://")[1])
+                    url = url.replace("://", "://{}@".format(valuespace.auth))
                 result = asm.download(url)
                 if result != asm.status_ok:
                     print(result)
@@ -125,7 +167,7 @@ class ServiceManager:
                             if valuespace.key.lower().endswith(asm.text_extensions):
                                 result = asm.set_xml(component, valuespace.key, valuespace.value)
                             else:
-                                result = asm.set_json(valuespace.key, valuespace.value, component)
+                                result = asm.set_json(component=component, key=valuespace.key, value=valuespace.value)
                             if result != asm.status_ok:
                                 print(result)
                     else:
@@ -212,6 +254,11 @@ class ServiceManager:
 
         elif valuespace.command == "delete":
             if valuespace.component:
+                # if "all" in valuespace.component:
+                #     result = asm.delete_files("all")
+                #     if result != asm.status_ok:
+                #         print(result)
+                # elif:
                 for component in valuespace.component:
                     if component.endswith(('zip', 'tar.gz')):
                         result = asm.delete_files(component)
@@ -348,7 +395,7 @@ class ServiceManager:
                     component = component_id
                 if not bool(valuespace.value or valuespace.key):
                     result = asm.get_task(component)
-                    if result != asm.status_fail:
+                    if result and result != asm.status_fail:
                         if isinstance(result, dict):
                             json_print(result)
                         elif isinstance(result, list):
@@ -363,10 +410,12 @@ class ServiceManager:
                     if result:
                         if isinstance(result, list):
                             for res in result:
-                                print(asm.get_task(res)[valuespace.key])
+                                res_value = asm.get_task(res)[valuespace.key]
+                                if res_value: print(res_value)
                         else:
                             try:
-                                print(result[valuespace.key])
+                                res = result[valuespace.key]
+                                if res: print(result[valuespace.key])
                             except KeyError as exception:
                                 traceback.print_exc()
                 else:
@@ -426,6 +475,9 @@ class ServiceManager:
                                 asm.cert_upload(path.join(cert, f))
             elif valuespace.info:
                 print(asm.cert_info())
+            elif valuespace.list:
+                for item in asm.cert_list():
+                    print(item)
             elif valuespace.download != None:
                 asm.download_certificate(valuespace.download)
             elif valuespace.truststore != None:
